//=========================================
// Window generator macro for Pov-ray 3.1 & higher
// (c) 2000 Gilles Tran tran@inapg.inra.fr
//=========================================
// Example of usage
// Gilles Tran - June 2000
// --------------------------------------
#include "colors.inc"
#include "mwindow.pov"

#declare PdV=<0,4,-30>;
#declare PdA=<0,5,0>;
camera{location PdV direction 2*z up y sky y right x*4/3  look_at PdA}

light_source{0 White*2 translate <-200, 400, -300>}
light_source{PdA White*0.3 shadowless}
// ==================================================================
// common parameters & textures
// --------------------------------------
#declare rd=seed(18908);
#declare xL=3;
#declare yL=9;
#declare txtFen1=texture{pigment{ForestGreen}}         
#declare txtFen2=texture{pigment{White}}
#declare txtVit1=texture{pigment{Clear}}
#declare txtBalcon1=texture{pigment{Green*0.3}}
#declare txtBalcon2=texture{pigment{rgb<1,0.9,0.8>*1.3}}
#declare txtTF=texture{pigment{rgb<1,0.9,0.8>*1.3}}
#declare txtToit=texture{pigment{rgb<0.8,0.7,0.9>*0.3}}
#declare txtV1=texture{pigment{SkyBlue}}
#declare txtV2=texture{pigment{rgb<1,0.8,0.5>}}
//--------------------------------
//Etage
#declare colWall=rgb<1,0.9,0.7>;
#declare txtWall=
texture{pigment{gradient y 
pigment_map{[0 colWall][1.0 colWall]}}
//normal {agate 0.7}
finish{ambient 0.01 specular 0.03 roughness 0.005} scale 32 translate -y*3}

// ==================================================================
// 3 x 2 windows (closed and open)
//-----------------------------------------
// Type 1 = one pane
//-----------------------------------------
// closed
#declare Window_1_c=object{mWindow(1,xL,yL,0.2,0.3,0.1,0.1,0,2,0,0,0.5,0.1,txtFen1,txtFen2,txtVit1)}
// part open
#declare Window_1_o=object{mWindow(1,xL,yL,0.2,0.3,0.1,0.1,0,2,-120,-110,0.5,0.1,txtFen1,txtFen2,txtVit1)}
//-----------------------------------------
// Type 2 = two panes
//-----------------------------------------
// closed, 0 vertical bars, 2 horizontal bars
#declare Window_2_c1=object{mWindow(2,xL,yL,0.2,0.3,0.1,0.1,0,2,0,0,0.5,0.1,txtFen1,txtFen2,txtVit1)}
// part open, 0 vertical bars, 2 horizontal bars
#declare Window_2_o1=object{mWindow(2,xL,yL,0.2,0.3,0.1,0.1,0,2,-40,-50,0.5,0.1,txtFen1,txtFen2,txtVit1)}
// closed, 1 vertical bars, 3 horizontal bars
#declare Window_2_c2=object{mWindow(2,xL,yL,0.2,0.3,0.1,0.1,1,3,0,0,0.5,0.1,txtFen1,txtFen2,txtVit1)}
// part open, 1 vertical bars, 3 horizontal bars
#declare Window_2_o2=object{mWindow(2,xL,yL,0.2,0.3,0.1,0.1,1,3,-130,-150,0.5,0.1,txtFen1,txtFen2,txtVit1)}
//-----------------------------------------
// Type 3 = vertical sliding
//-----------------------------------------
// closed
#declare Window_3_c=object{mWindow(3,xL,yL,0.2,0.3,0.1,0.1,0,0,0,0,0.5,0.1,txtFen1,txtFen2,txtVit1)}
// part open (60%)
#declare Window_3_o1=object{mWindow(3,xL,yL,0.2,0.3,0.1,0.1,0,0,60,0,0.5,0.1,txtFen1,txtFen2,txtVit1)}
// fully open
#declare Window_3_o2=object{mWindow(3,xL,yL,0.2,0.3,0.1,0.1,0,0,100,0,0.5,0.1,txtFen1,txtFen2,txtVit1)}

//-----------------------------------------
// Type 4 = horizontal sliding
//-----------------------------------------
// closed
#declare Window_4_c=object{mWindow(4,xL,yL,0.2,0.3,0.1,0.1,0,0,0,0,0.5,0.1,txtFen1,txtFen2,txtVit1)}
// part open (60%)
#declare Window_4_o1=object{mWindow(4,xL,yL,0.2,0.3,0.1,0.1,0,0,60,0,0.5,0.1,txtFen1,txtFen2,txtVit1)}
// fully open
#declare Window_4_o2=object{mWindow(4,xL,yL,0.2,0.3,0.1,0.1,0,0,100,0,0.5,0.1,txtFen1,txtFen2,txtVit1)}

// ==================================================================
// 2 x 6 balconies types (with or without ledge)
//-----------------------------------------
// Type 1 = horizontal bars
//-----------------------------------------
#declare Balcony_1_wl=object{mBalcony(1,xL+1 ,3,1  ,0.1,0.5,0.5,5,txtBalcon1)} //(with ledge)
#declare Balcony_1_nl=object{mBalcony(1,xL ,3,0  ,0.1,0.5,0.5,5,txtBalcon1)} //(no ledge)
//-----------------------------------------
// Type 2 = old style
//-----------------------------------------
#declare Balcony_2_wl=object{mBalcony(2,xL+1,4,1.3,0.1,0.5,0  ,5,txtBalcon1)} //(with ledge)
#declare Balcony_2_nl=object{mBalcony(2,xL,4,0  ,0.1,0.5,0  ,5,txtBalcon1)} //(no ledge)
//-----------------------------------------
// Type 3 = crossed bars XXXXXX
//-----------------------------------------
#declare Balcony_3_wl=object{mBalcony(3,xL+1,3,1.3,0.1,0.5,0  ,5,txtBalcon1)} //(with ledge)
#declare Balcony_3_nl=object{mBalcony(3,xL,3,0  ,0.1,0.5,0  ,5,txtBalcon1)} //(with ledge)
//-----------------------------------------
// Type 4 = stone ornaments 1
//-----------------------------------------
#declare Balcony_4_wl=object{mBalcony(4,xL+1,3,2.6,0.2,0.12,0 ,10,txtBalcon2)} //(with ledge)
#declare Balcony_4_nl=object{mBalcony(4,xL,3,0  ,0.2,0.12,0  ,10,txtBalcon2)} //(no ledge)
//-----------------------------------------
// Type 5 = stone ornaments 2
//-----------------------------------------
#declare Balcony_5_wl=object{mBalcony(5,xL+1,3,2.6 ,0.2,0.12,0,10,txtBalcon2)} //(width ledge)
#declare Balcony_5_nl=object{mBalcony(5,xL  ,3,0 ,0.2,0.12,0,10,txtBalcon2)} //(no ledge)
//-----------------------------------------
// Type 6 = vertical bars
//-----------------------------------------
#declare Balcony_6_wl=object{mBalcony(6,xL+1,3,3  ,0.1,0.2,0  ,10,txtBalcon1)} //(width ledge)
#declare Balcony_6_nl=object{mBalcony(6,xL,3,0  ,0.1,0.2,0  ,10,txtBalcon1)} //(no ledge)
//-----------------------------------------

// ==================================================================
// 2 x 8 window case types
// Window cases with ledges should be used with balconies with ledge
// so that the balcony doesn't hang on emptiness
//-----------------------------------------
// Type 1 : Triangle roof & side ornaments
//-----------------------------------------
// with ledge (for balcony)
#declare WCase_1_wl=object{mWindowCase(1,xL,yL,0.4,1,0.1,  0,1,  0,0.5,3.5,txtTF,txtToit)}
// small ledge
#declare WCase_1_nl=object{mWindowCase(1,xL,yL,0.4,1,0.1,  0,1,  0,0.5,0.5,txtTF,txtToit)}
//-----------------------------------------
// Type 2 : Rounded roof & side ornaments
//-----------------------------------------
// with ledge (for balcony)
#declare WCase_2_wl=object{mWindowCase(2,xL,yL,0.4,1,0.1,  0,1,  2,0.5,3.5,txtTF,txtToit)}
// small ledge
#declare WCase_2_nl=object{mWindowCase(2,xL,yL,0.4,1,0.1,  0,1,  2,0.5,0.5,txtTF,txtToit)}
//-----------------------------------------
// Type 3 : Complex square case
//-----------------------------------------
// with ledge (for balcony)
#declare WCase_3_wl=object{mWindowCase(3,xL,yL,0.4,1,0.1,  0,0,  0,0.5,3.5,txtTF,txtToit)}
// small ledge
#declare WCase_3_nl=object{mWindowCase(3,xL,yL,0.4,1,0.1,  0,0,  0,0.5,0.5,txtTF,txtToit)}
//-----------------------------------------
// Type 4 : Simple square case
//-----------------------------------------
// with ledge (for balcony)
#declare WCase_4_wl=object{mWindowCase(4,xL,yL,0.4,1,0.1,0.6,0,  0,0.5,3.5,txtTF,txtToit)}
// small ledge
#declare WCase_4_nl=object{mWindowCase(4,xL,yL,0.4,1,0.1,0.6,0,  0,0.5,0.5,txtTF,txtToit)}
//-----------------------------------------
// Type 5 : Triangular garret
//-----------------------------------------
// with ledge (for balcony)
#declare WCase_5_wl=object{mWindowCase(5,xL,yL, 25,1,0.1,0.2,2,0.1,0.5,3.5,txtTF,txtToit)}
// small ledge
#declare WCase_5_nl=object{mWindowCase(5,xL,yL, 25,1,0.1,0.2,2,0.1,0.5,0.5,txtTF,txtToit)}
//-----------------------------------------
// Type 6 : Rounded garret
//-----------------------------------------
// with ledge (for balcony)
#declare WCase_6_wl=object{mWindowCase(6,xL,yL, 25,1,0.1,0.2,2,0.1,0.5,3.5,txtTF,txtToit)}
// small ledge
#declare WCase_6_nl=object{mWindowCase(6,xL,yL, 25,1,0.1,0.2,2,0.1,0.5,0.5,txtTF,txtToit)}
//-----------------------------------------
// Type 7 : Sloped garret (to be used on a sloped roof)
//-----------------------------------------
// with ledge (for balcony)
#declare WCase_7_wl=object{mWindowCase(7,xL,yL, 10,1,0.1,0.2,7,0.1,1,3.5,txtTF,txtToit)}
// small ledge
#declare WCase_7_nl=object{mWindowCase(7,xL,yL, 10,1,0.1,0.2,7,0.1,1,0.5,txtTF,txtToit)}
//-----------------------------------------
// Type 8 : Simple ledge
//-----------------------------------------
// with ledge (for balcony)
#declare WCase_8_wl=object{mWindowCase(8,xL,yL,0,0.3,0,0,0,0,1,3.5,txtTF,txtToit)}
// small ledge
#declare WCase_8_nl=object{mWindowCase(8,xL,yL,0,0.3,0,0,0,0,1,1,txtTF,txtToit)}
//-----------------------------------------

// ==================================================================
// 2 x 6 shutter types (closed or open)
// Type 1 to 4 : change the angle values for opening
//-----------------------------------------
// Type 1 : simple shutter on vertical hinge
//-----------------------------------------
// closed
#declare Shutter_1_c=object{mShutter(1,xL,yL,0.2,0.3,20,5,2,0,0.7,0.1,rd,0.05,txtV1) }
// open
#declare Shutter_1_o=object{mShutter(1,xL,yL,0.2,0.3,20,175,175,0,0.7,0.1,rd,0.01,txtV1)}
//-----------------------------------------
// Type 2 : simple shutter on horizontal hinge
//-----------------------------------------
// closed
#declare Shutter_2_c=object{mShutter(2,xL,yL,0.2,0.3,20,5,1,0,0.7,0.1,rd,0.01,txtV1)}
// half-open
#declare Shutter_2_o=object{mShutter(2,xL,yL,0.2,0.3,20,5,51,0,0.7,0.1,rd,0.01,txtV1)}
//-----------------------------------------
// Type 3 : classic 2 panes shutter (left and right)
//-----------------------------------------         
// closed
#declare Shutter_3_c=object{mShutter(3,xL,yL,0.2,0.3,20,5,5,6,0.7,0.1,rd,0.5,txtV1)}
// open
#declare Shutter_3_o=object{mShutter(3,xL,yL,0.2,0.3,20,175,155,165,0.7,0.1,rd,0.5,txtV1)}
//-----------------------------------------
// Type 4 : classic 4 panes shutter (left and right)
//-----------------------------------------         
// closed
#declare Shutter_4_c=object{mShutter(4,xL,yL,0.2,0.3,20,5,5,6,0.7,0.1,rd,0.5,txtV1)}
// part open
#declare Shutter_4_o=object{mShutter(4,xL,yL,0.2,0.3,20,5,75,56,0.7,0.1,rd,0.5,txtV1)}
//-----------------------------------------
// Type 5 : slatted shutter (Venetian blind)
//-----------------------------------------         
// closed
#declare Shutter_5_c=object{mShutter(5,xL*0.9,yL,0.5,0.1,15,0,0,0,0.4,0.2,rd,0.1,txtV2)}
// half open
#declare Shutter_5_h=object{mShutter(5,xL*0.9,yL,0.5,0.1,8,0,0,0,0.4,0.2,rd,0.1,txtV2)}
// open
#declare Shutter_5_o=object{mShutter(5,xL*0.9,yL,0.5,0.1,3,0,0,0,0.4,0.2,rd,0.1,txtV2)}
//-----------------------------------------
// Type 6 : cloth blind
//-----------------------------------------         
// closed
#declare Shutter_6_c=object{mShutter(6,xL*0.9,yL,yL*0.8,0.1,0,0,0,0,0,0,rd,0.3,txtV2)}
// half open
#declare Shutter_6_h=object{mShutter(6,xL*0.9,yL,yL*0.5,0.1,0,0,0,0,0,0,rd,0.5,txtV2)}
// open
#declare Shutter_6_o=object{mShutter(6,xL*0.9,yL,yL*0.1,0.1,0,0,0,0,0,0,rd,0.5,txtV2)}

//==================================================================
// Uncomment the elements (window, balcony, case and shutter) you want to put together
// You may need to adjust the relative z positions of the elements
// Some types may be inconsistent with each other 
// a balcony should let you open the shutter !!!
// Also, closed shutters do not require a window
//-----------------------------------------
// Wall with a hole
#declare Wall=difference{box{<-100,-100,0>,<100,100,2>} box{<-xL,0,-10>,<xL,yL,100>} texture{txtWall}}

union{
//        object{Window_1_c translate z*2}
//        object{Window_1_o translate z*2}
//        object{Window_2_c1 translate z*2}
        object{Window_2_o1 translate z*2}
//        object{Window_2_c2 translate z*2}
//        object{Window_2_o2 translate z*2}
//        object{Window_3_c translate z*0.5}
//        object{Window_3_o1 translate z*0.5}
//        object{Window_3_o2 translate z*0.5}
//        object{Window_4_c translate z*0.5}
//        object{Window_4_o1 translate z*0.5}
//        object{Window_4_o2 translate z*0.5}

//        object{Balcony_1_wl}
//        object{Balcony_1_nl translate z*0.5}
//        object{Balcony_2_wl}
//        object{Balcony_2_nl translate z*0.5}
//        object{Balcony_3_wl}
//        object{Balcony_3_nl translate z*0.5}
//        object{Balcony_4_wl}
//        object{Balcony_4_nl translate z*0.5}
//        object{Balcony_5_wl}
//        object{Balcony_5_nl translate z*0.5}
//        object{Balcony_6_wl}
//        object{Balcony_6_nl translate z*0.5}

//        object{WCase_1_wl}
        object{WCase_1_nl}
//        object{WCase_2_wl}
//        object{WCase_2_nl}
//        object{WCase_3_wl}
//        object{WCase_3_nl}
//        object{WCase_4_wl}
//        object{WCase_4_nl}
//        object{WCase_5_wl}
//        object{WCase_5_nl}
//        object{WCase_6_wl}
//        object{WCase_6_nl}
//        object{WCase_7_wl}
//        object{WCase_7_nl}
//        object{WCase_8_wl}
//        object{WCase_8_nl}

//        object{Shutter_1_c}
//        object{Shutter_1_o}
//        object{Shutter_2_c}
//        object{Shutter_2_o}
//        object{Shutter_3_c}
        object{Shutter_3_o}
//        object{Shutter_4_c}
//        object{Shutter_4_o}
//        object{Shutter_5_c}
//        object{Shutter_5_o}
//        object{Shutter_6_c}
//        object{Shutter_6_o}
object{Wall}
rotate y*20
}

// some examples
//union{object{Window_3_c translate z*2} object{WCase_1_wl} object{Balcony_5_wl} object{Shutter_4_o} object{Wall} rotate y*20}
//union{object{WCase_2_wl} object{Balcony_4_wl} object{Shutter_4_c} object{Wall} rotate y*20}
//union{object{Window_3_c translate z*2} object{WCase_3_nl translate -z*0.2} object{Balcony_1_wl} object{Shutter_5_c} object{Wall} rotate y*20}
//union{object{Window_3_c translate z*2} object{WCase_4_nl translate -z*0.1} object{Balcony_3_nl} object{Shutter_6_h translate z*0.4} object{Wall} rotate y*20}
//union{object{Window_2_o translate z*0.5} object{WCase_5_nl} object{Shutter_3_o} rotate y*20}
//union{object{WCase_6_nl} object{Shutter_3_c} rotate y*20}
//union{object{Window_2_c translate z*0.5} object{WCase_7_nl} object{Shutter_2_o} rotate y*20}
background{rgb<0.9,0.98,1>}
